@@ -7,30 +7,25 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
+#include <string.h>
 #include <linux/kd.h>
-#include <sys/ioctl.h>
+#include "kdmapop.h"
 #include "getfd.h"
 #include "nls.h"
 
 int
 main(int argc, char *argv[]) {
-	struct unimapinit advice;
 	int fd;
+	char *console = NULL;
 
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 
-	fd = getfd();
+	if (argc >= 3 && !strcmp(argv[1], "-C"))
+		console = argv[2];
 
-	advice.advised_hashsize = 0;
-	advice.advised_hashstep = 0;
-	advice.advised_hashlevel = 0;
+	fd = getfd(console);
 
-	if(ioctl(fd, PIO_UNIMAPCLR, &advice)) {
-		perror("PIO_UNIMAPCLR");
-		exit(1);
-	}
-
-	return 0;
+	return loadunimap (fd, NULL, NULL);
 }
