@@ -3,6 +3,7 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <memory.h>
 #include <string.h>
 #include <fcntl.h>
@@ -51,7 +52,7 @@ main(int argc, char *argv[]) {
 		argv++;
 	}
 
-	fd = getfd();
+	fd = getfd(NULL);
 
 	if (argc >= 3 && !strcmp(argv[1], "-o")) {
 	    saveoldmap(fd, argv[2]);
