@@ -5,18 +5,21 @@
  *
  */
 #include <signal.h>
+#include <errno.h>
 #include <linux/kd.h>
 
 void
 sighup(){
-    system("open -s -l -- login -h spawn");
+    system("openvt -s -l -- login -h spawn");
     signal(SIGHUP, sighup);
 }
 
 main(){
     int fd;
 
-    fd = open("/dev/console", 0);
+    fd = open("/dev/tty0", 0);
+    if (fd < 0 && errno == ENOENT)
+      fd = open("/dev/vc/0", 0);
     if (fd < 0)
       fd = 0;
     signal(SIGHUP, sighup);
